<p align="center">
    <a href="https://codecov.io/gh/maximshumilo/fastapi-restful-extension">
        <img src="https://codecov.io/gh/maximshumilo/fastapi-restful-extension/branch/master/graph/badge.svg?token=ZAU44DIGQJ"/>
    </a>
    <a href="https://github.com/maximshumilo/fastapi-restful-extension/actions?query=workflow%3ATest+event%3Apush+branch%3Amaster" target="_blank">
        <img src="https://github.com/maximshumilo/fastapi-restful-extension/actions/workflows/main.yml/badge.svg">
    </a>
    <a href="https://github.com/maximshumilo/fastapi-restful-extension/actions?query=workflow%3ATest+event%3Apush+branch%3Amaster" target="_blank">
        <img src="https://img.shields.io/pypi/v/fastapi-restful-extension?color=%2374c954">
    </a>
    <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/fastapi-restful-extension?color=%2378c55b">
</p>

<p align="center">
    <em>fastapi-restful-extension - FastAPI extension that allows you to easily create a RESTful API</em>
</p>
